/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_gxwFO989);
  numBytes += sLine_init(&sLine_zeFk6pyy);
  numBytes += sTabhead_init(&sTabhead_VbyPfMSZ, &hTable_TfV2blPI);
  numBytes += sTabread_init(&sTabread_1HvihHyN, &hTable_TfV2blPI, false);
  numBytes += sTabread_init(&sTabread_kk8ygNHo, &hTable_TfV2blPI, false);
  numBytes += sLine_init(&sLine_MEXulILt);
  numBytes += sLine_init(&sLine_61g6OSaT);
  numBytes += sLine_init(&sLine_gLw4oy6q);
  numBytes += sTabhead_init(&sTabhead_D9sEyqX6, &hTable_LUzDY6gR);
  numBytes += sTabread_init(&sTabread_5S5weeRm, &hTable_LUzDY6gR, false);
  numBytes += sTabread_init(&sTabread_JsBZI3XX, &hTable_LUzDY6gR, false);
  numBytes += sLine_init(&sLine_fnkWmsnG);
  numBytes += sTabwrite_init(&sTabwrite_vixq5Sy5, &hTable_TfV2blPI);
  numBytes += sTabwrite_init(&sTabwrite_6o8cDw3J, &hTable_LUzDY6gR);
  numBytes += sRPole_init(&sRPole_zmvoENBp);
  numBytes += sRPole_init(&sRPole_j9VqJVLq);
  numBytes += sRPole_init(&sRPole_VPBHWT7u);
  numBytes += sDel1_init(&sDel1_6weNRpqS);
  numBytes += sLine_init(&sLine_NP6N0s0p);
  numBytes += sLine_init(&sLine_bmar2HZ6);
  numBytes += sRPole_init(&sRPole_zNmb6EIY);
  numBytes += sRPole_init(&sRPole_qYY1qWxi);
  numBytes += sRPole_init(&sRPole_xVcd8lRH);
  numBytes += sDel1_init(&sDel1_dqJ3X2xH);
  numBytes += sLine_init(&sLine_uqfiFSQu);
  numBytes += sLine_init(&sLine_ow0ttbRE);
  numBytes += sLine_init(&sLine_OM3ucBfz);
  numBytes += sLine_init(&sLine_cfv8n2I7);
  numBytes += cVar_init_f(&cVar_Gt6fYIhR, 0.0f);
  numBytes += cVar_init_f(&cVar_1cSS2mOT, 0.0f);
  numBytes += cVar_init_f(&cVar_ml5527J9, 0.0f);
  numBytes += cVar_init_f(&cVar_Ko5mwmSy, 0.0f);
  numBytes += cSlice_init(&cSlice_PfMhLTu0, 1, -1);
  numBytes += cVar_init_f(&cVar_BSAXKyzb, 0.5f);
  numBytes += cSlice_init(&cSlice_4kcN9iZZ, 1, -1);
  numBytes += cVar_init_f(&cVar_rpeHhHtp, 0.2f);
  numBytes += cSlice_init(&cSlice_soPyc0SF, 1, -1);
  numBytes += cVar_init_f(&cVar_AQuSoztp, 500.0f);
  numBytes += cSlice_init(&cSlice_t4rIlW9t, 1, -1);
  numBytes += cVar_init_f(&cVar_dJdklOMX, 0.25f);
  numBytes += cDelay_init(this, &cDelay_3RASuu54, 0.0f);
  numBytes += cDelay_init(this, &cDelay_sIDPMvPa, 0.0f);
  numBytes += hTable_init(&hTable_TfV2blPI, 256);
  numBytes += cDelay_init(this, &cDelay_f0SNyO9j, 0.0f);
  numBytes += cDelay_init(this, &cDelay_czikzJ3U, 0.0f);
  numBytes += hTable_init(&hTable_LUzDY6gR, 256);
  numBytes += cVar_init_f(&cVar_26EQTCpM, 8000.0f);
  numBytes += cBinop_init(&cBinop_j2WjOsjY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_txD6DgY9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H6e5FeTl, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NhqZWAa5, 8000.0f);
  numBytes += cBinop_init(&cBinop_kK8ajIi3, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_dqwK7xJ8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5QABb7iq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HrQ4YocT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8MFSqEpE, 300.0f);
  numBytes += cBinop_init(&cBinop_CtNdzgpN, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_1AHcQzVE, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_DxOXCT8k, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_JkjsrNEk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4N8lnchi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dPqDRblm, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_NHrwzgo1, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_Z5qwjVKB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KnM4ELNa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5LgDs90I, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_5p4BOusn, 8000.0f);
  numBytes += cBinop_init(&cBinop_Lv4ytro0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9KITpXg2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PXk0bL5q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YMPYMd6H, 8000.0f);
  numBytes += cBinop_init(&cBinop_qbpMnPmt, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wQK5cYWk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YzlDBGEp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VgP2w9PN, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_BDz01HWz, 300.0f);
  numBytes += cBinop_init(&cBinop_jpnTduaf, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_9OJvCfma, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2OAluRwq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y4iE2sk2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Yv33RGcG, 1.0f);
  numBytes += cIf_init(&cIf_sKlWSWzv, false);
  numBytes += cIf_init(&cIf_uxgki5ul, false);
  numBytes += cVar_init_f(&cVar_IWNzg94E, 0.0f);
  numBytes += cVar_init_f(&cVar_PV4FTFt4, 0.0f);
  numBytes += cVar_init_f(&cVar_OtRIvBLG, 60000.0f);
  numBytes += cVar_init_f(&cVar_S2jk4WxG, 500.0f);
  numBytes += cSlice_init(&cSlice_KqYOxfcu, 1, -1);
  numBytes += cSlice_init(&cSlice_5AK9wjlz, 1, -1);
  numBytes += cVar_init_f(&cVar_rUHOnXCp, 0.0f);
  numBytes += cIf_init(&cIf_Tl6386OE, false);
  numBytes += cBinop_init(&cBinop_JPOA9hWr, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_2hCozj8a, 120.0f);
  numBytes += cBinop_init(&cBinop_Rj9cflCT, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Q91CPWk9, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_TfV2blPI);
  hTable_free(&hTable_LUzDY6gR);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_TfV2blPI; // del-1011-delayL
    case 0xF057CB49: return &hTable_LUzDY6gR; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ikQHHTxs_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lHZBcB3r_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FNyDlvzq_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RgRCEaM4_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UE041BDP_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WBwOH9CS_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yn8FDu6N_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TzcNOhzP_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P1Oke2AV_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HjwqHJKq_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_auBMXn1v_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZV5ueMWm_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_Gt6fYIhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OiEWipTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_1cSS2mOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bi6DRJiD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_ml5527J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2YbbZUe9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_Ko5mwmSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e9DsVvBS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_qUdvZZe7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PfMhLTu0, 0, m, &cSlice_PfMhLTu0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_PfMhLTu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_A2BuAynL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_A2BuAynL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_BSAXKyzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A2BuAynL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_A2BuAynL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P1Oke2AV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_5y0pezPC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4kcN9iZZ, 0, m, &cSlice_4kcN9iZZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Id2ZQVr7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_4kcN9iZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nkkRLXOz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nkkRLXOz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_rpeHhHtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nkkRLXOz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_nkkRLXOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yn8FDu6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_wPAmgskD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_soPyc0SF, 0, m, &cSlice_soPyc0SF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qUdvZZe7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_soPyc0SF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zYyULKgY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zYyULKgY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_AQuSoztp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zYyULKgY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_zYyULKgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HjwqHJKq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_mtHl1ARA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JFvB0X4P_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JFvB0X4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_wWIHkNXg_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_m8OqmaYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wLUJNAjd_sendMessage(_c, 0, m);
  cMsg_gjPn36df_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_HEpwEQUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zvhQvLju_sendMessage(_c, 0, m);
  cMsg_ByiYYReI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_wWIHkNXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n2iE2Lnq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_n2iE2Lnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kq2ORtgF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DzqB5EWn_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_DzqB5EWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DS44BL5L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Kq2ORtgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VHM5HWLP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_VHM5HWLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qow1HSfJ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_DS44BL5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_b7ruB66S_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_b7ruB66S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FbnY3yAX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qow1HSfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_m8OqmaYr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_FbnY3yAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_HEpwEQUR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_30UdZL9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UorI8FTr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_UorI8FTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_DKAizPvL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_DKAizPvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IG2Or2Bt_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IG2Or2Bt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uW7jVuwN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x4J6TZkh_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_x4J6TZkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mGJkQ9Xj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_uW7jVuwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nHrKD2To_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nHrKD2To_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cmJ6iSut_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_mGJkQ9Xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JVLRZIjp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JVLRZIjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_k93fES3M_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_k93fES3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vamQSROo_sendMessage(_c, 0, m);
  cMsg_OsaVzxSk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_cmJ6iSut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wkSMhsYd_sendMessage(_c, 0, m);
  cMsg_PuOeIAYz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_Id2ZQVr7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_t4rIlW9t, 0, m, &cSlice_t4rIlW9t_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wPAmgskD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_t4rIlW9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IBXjcjsf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IBXjcjsf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_dJdklOMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IBXjcjsf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_IBXjcjsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TzcNOhzP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_pX4LPONC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v3Jcp9AY_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_v3Jcp9AY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5mf3ffbI_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_3RASuu54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3RASuu54, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sIDPMvPa, 0, m, &cDelay_sIDPMvPa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3RASuu54, 0, m, &cDelay_3RASuu54_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vixq5Sy5, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_sIDPMvPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sIDPMvPa, m);
  cMsg_Uj2UCjSI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_i64sUe8i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_BHuLcZ2m_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_if17F6Pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kfjPyJZk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_TfV2blPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z4mM64pt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3RASuu54, 2, m, &cDelay_3RASuu54_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IC7fq1rJ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_kfjPyJZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TfV2blPI, 0, m, &hTable_TfV2blPI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5mf3ffbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_if17F6Pn_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Uj2UCjSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TfV2blPI, 0, m, &hTable_TfV2blPI_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_IC7fq1rJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3RASuu54, 0, m, &cDelay_3RASuu54_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_z4mM64pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_sIDPMvPa, 2, m, &cDelay_sIDPMvPa_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BHuLcZ2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_vixq5Sy5, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_GxcEz6Rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_e4Psc7F9_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_e4Psc7F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JvxVfugE_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_f0SNyO9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f0SNyO9j, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_czikzJ3U, 0, m, &cDelay_czikzJ3U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_f0SNyO9j, 0, m, &cDelay_f0SNyO9j_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6o8cDw3J, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_czikzJ3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_czikzJ3U, m);
  cMsg_j4vk8QDx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_jWmguPP4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_gCJpdZ2A_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_bYn3nXTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n9p7YZ2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_LUzDY6gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dZJEczVT_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_f0SNyO9j, 2, m, &cDelay_f0SNyO9j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mxFMT6MC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_n9p7YZ2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LUzDY6gR, 0, m, &hTable_LUzDY6gR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JvxVfugE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_bYn3nXTC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_j4vk8QDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LUzDY6gR, 0, m, &hTable_LUzDY6gR_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_mxFMT6MC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f0SNyO9j, 0, m, &cDelay_f0SNyO9j_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_dZJEczVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_czikzJ3U, 2, m, &cDelay_czikzJ3U_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gCJpdZ2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6o8cDw3J, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_26EQTCpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j2WjOsjY, HV_BINOP_MULTIPLY, 0, m, &cBinop_j2WjOsjY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_eGyfLUXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lFIXYn0w_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_lFIXYn0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AkkhdyTn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_j2WjOsjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZW80hD8g_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_t0wxXTvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j2WjOsjY, HV_BINOP_MULTIPLY, 1, m, &cBinop_j2WjOsjY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_AkkhdyTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_t0wxXTvj_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZW80hD8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LLEBW9WD_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_LLEBW9WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wl6dWnnx_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_H6e5FeTl, m);
}

void Heavy_WSTD_DLAY::cBinop_wl6dWnnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_txD6DgY9, m);
}

void Heavy_WSTD_DLAY::cVar_NhqZWAa5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kK8ajIi3, HV_BINOP_MULTIPLY, 0, m, &cBinop_kK8ajIi3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_TxPLTAVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LR8oAYdL_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_LR8oAYdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BTRFSUi0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_kK8ajIi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Z8g934bb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_zntMxoWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kK8ajIi3, HV_BINOP_MULTIPLY, 1, m, &cBinop_kK8ajIi3_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BTRFSUi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zntMxoWr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Z8g934bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YlxKu07g_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YlxKu07g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FpPfT3lD_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5QABb7iq, m);
}

void Heavy_WSTD_DLAY::cBinop_FpPfT3lD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dqwK7xJ8, m);
}

void Heavy_WSTD_DLAY::cBinop_jwMjB3VK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yI1JxFyE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yI1JxFyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_43BqP3OL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_y5KwaLdt_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_8MFSqEpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_kUbJqQCv_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lYuJ90ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mJ33lsU0_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_mJ33lsU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtNdzgpN, HV_BINOP_DIVIDE, 1, m, &cBinop_CtNdzgpN_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_43BqP3OL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KmnehYSy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KmnehYSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1AHcQzVE, m);
}

void Heavy_WSTD_DLAY::cMsg_Zl3gbX5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rr9HGhMV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rr9HGhMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jwMjB3VK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_y5KwaLdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HrQ4YocT, m);
}

void Heavy_WSTD_DLAY::cBinop_kUbJqQCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_N07ovToK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_N07ovToK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtNdzgpN, HV_BINOP_DIVIDE, 0, m, &cBinop_CtNdzgpN_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CtNdzgpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zl3gbX5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_ATUTELkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FwGP8BAn_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_FwGP8BAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_vKt4qXdf_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_DxOXCT8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NxE6mV5I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_HUmXfqeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_x1Ys8Ap9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JkjsrNEk, m);
}

void Heavy_WSTD_DLAY::cBinop_vKt4qXdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4N8lnchi, m);
}

void Heavy_WSTD_DLAY::cMsg_NxE6mV5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HUmXfqeH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_x1Ys8Ap9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dPqDRblm, m);
}

void Heavy_WSTD_DLAY::cMsg_2PzOfSyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LIcPHpFO_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_LIcPHpFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_PI2tcDDy_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_NHrwzgo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w93A4aDE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_ibj1drtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qvgpeR8j_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z5qwjVKB, m);
}

void Heavy_WSTD_DLAY::cBinop_PI2tcDDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KnM4ELNa, m);
}

void Heavy_WSTD_DLAY::cMsg_w93A4aDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ibj1drtO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qvgpeR8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5LgDs90I, m);
}

void Heavy_WSTD_DLAY::cVar_5p4BOusn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lv4ytro0, HV_BINOP_MULTIPLY, 0, m, &cBinop_Lv4ytro0_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_g0DzuWq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fHYsC60H_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_fHYsC60H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HiDsDmja_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_Lv4ytro0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_W07SYIhr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wT7iOfyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lv4ytro0, HV_BINOP_MULTIPLY, 1, m, &cBinop_Lv4ytro0_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_HiDsDmja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wT7iOfyf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_W07SYIhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_b2VQTX5T_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_b2VQTX5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rDcVSxWN_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PXk0bL5q, m);
}

void Heavy_WSTD_DLAY::cBinop_rDcVSxWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9KITpXg2, m);
}

void Heavy_WSTD_DLAY::cVar_YMPYMd6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qbpMnPmt, HV_BINOP_MULTIPLY, 0, m, &cBinop_qbpMnPmt_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_MVMmkOGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_421FS7Em_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_421FS7Em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fz2GaDPT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_qbpMnPmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PJJxh7cP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4TccUNwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qbpMnPmt, HV_BINOP_MULTIPLY, 1, m, &cBinop_qbpMnPmt_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fz2GaDPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4TccUNwG_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PJJxh7cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_s3GyVxpK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_s3GyVxpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Dwcd2lMm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YzlDBGEp, m);
}

void Heavy_WSTD_DLAY::cBinop_Dwcd2lMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wQK5cYWk, m);
}

void Heavy_WSTD_DLAY::cBinop_Gmuji5rl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hpgBxkzx_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_hpgBxkzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1dpI2xap_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MsQWFtcD_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_BDz01HWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_NX7WUN9W_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_DLnRty3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VCUUr2Ls_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_VCUUr2Ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jpnTduaf, HV_BINOP_DIVIDE, 1, m, &cBinop_jpnTduaf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1dpI2xap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cuUIGE70_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_cuUIGE70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9OJvCfma, m);
}

void Heavy_WSTD_DLAY::cMsg_LLaYLMl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Oc8vIAU3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Oc8vIAU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Gmuji5rl_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MsQWFtcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VgP2w9PN, m);
}

void Heavy_WSTD_DLAY::cBinop_NX7WUN9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_NX1FtGcD_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NX1FtGcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jpnTduaf, HV_BINOP_DIVIDE, 0, m, &cBinop_jpnTduaf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_jpnTduaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LLaYLMl6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_wLUJNAjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MEXulILt, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_zvhQvLju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gxwFO989, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_ByiYYReI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_61g6OSaT, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_gjPn36df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fnkWmsnG, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_PuOeIAYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ow0ttbRE, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_vamQSROo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bmar2HZ6, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_wkSMhsYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cfv8n2I7, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_OsaVzxSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OM3ucBfz, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_wEDxKR0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zeFk6pyy, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_0zF5TXL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gLw4oy6q, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_K3vptuR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NP6N0s0p, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_cw9Ufda1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uqfiFSQu, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_Yv33RGcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_knJVgA6S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uslgnUbr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0hCh8PE0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_knJVgA6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yv33RGcG, 1, m, &cVar_Yv33RGcG_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_sKlWSWzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_1cSS2mOT, 0, m, &cVar_1cSS2mOT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_uxgki5ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_1cSS2mOT, 0, m, &cVar_1cSS2mOT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_IWNzg94E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uxgki5ul, 0, m, &cIf_uxgki5ul_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_PV4FTFt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sKlWSWzv, 0, m, &cIf_sKlWSWzv_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_OtRIvBLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rj9cflCT, HV_BINOP_DIVIDE, 0, m, &cBinop_Rj9cflCT_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_S2jk4WxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q91CPWk9, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q91CPWk9_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_A6l08kyu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KqYOxfcu, 0, m, &cSlice_KqYOxfcu_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5AK9wjlz, 0, m, &cSlice_5AK9wjlz_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QSPya0fY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nCAvHKZb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_KqYOxfcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_rUHOnXCp, 0, m, &cVar_rUHOnXCp_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_rUHOnXCp, 0, m, &cVar_rUHOnXCp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_5AK9wjlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JPOA9hWr, HV_BINOP_NEQ, 1, m, &cBinop_JPOA9hWr_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_rUHOnXCp, 1, m, &cVar_rUHOnXCp_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JPOA9hWr, HV_BINOP_NEQ, 1, m, &cBinop_JPOA9hWr_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_rUHOnXCp, 1, m, &cVar_rUHOnXCp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_rUHOnXCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_1oyFP6oV_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_Tl6386OE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EcNMKCGA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yom9uCST_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_EcNMKCGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPOA9hWr, HV_BINOP_NEQ, 1, m, &cBinop_JPOA9hWr_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Yom9uCST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rUHOnXCp, 0, m, &cVar_rUHOnXCp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JPOA9hWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tl6386OE, 1, m, &cIf_Tl6386OE_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_nCAvHKZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tl6386OE, 0, m, &cIf_Tl6386OE_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_QSPya0fY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPOA9hWr, HV_BINOP_NEQ, 0, m, &cBinop_JPOA9hWr_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_2hCozj8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VtbWcpR4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VcoLRQ3d_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_uLAWOqIh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RYyNaK7T_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_42uOg0ob_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ogSClmNq_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CCnpsCK8_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ijXrf6wi_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vn1HY2wv_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oDVHrlyb_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oeXHqgNV_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pm6RdNSu_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ADdob9vp_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jOoQfPg2_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vQ21mnwC_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J363i4NE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_RYyNaK7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bPZzxKDg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_42uOg0ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UAA8ISVT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ogSClmNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UmVDlqLc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_CCnpsCK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4PQTAu2q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ijXrf6wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u035d6dc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_vn1HY2wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cWbObzA8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_oDVHrlyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RITZ3aTJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_oeXHqgNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_spHcvZFK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Pm6RdNSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oSUxAq7B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ADdob9vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ElaMHQ0X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_jOoQfPg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9aHh0TRi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_vQ21mnwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ojC8jOVO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_J363i4NE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dNzZUP2E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_Rj9cflCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q91CPWk9, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q91CPWk9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Q91CPWk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_A6l08kyu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_VtbWcpR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rj9cflCT, HV_BINOP_DIVIDE, 1, m, &cBinop_Rj9cflCT_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_VcoLRQ3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OtRIvBLG, 0, m, &cVar_OtRIvBLG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S2jk4WxG, 0, m, &cVar_S2jk4WxG_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Wv8GSDUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OtRIvBLG, 0, m, &cVar_OtRIvBLG_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Lsxyebbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S2jk4WxG, 0, m, &cVar_S2jk4WxG_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bPZzxKDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_UAA8ISVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_UmVDlqLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_4PQTAu2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_u035d6dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cWbObzA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_RITZ3aTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_spHcvZFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_oSUxAq7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ElaMHQ0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9aHh0TRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ojC8jOVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_dNzZUP2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lsxyebbx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wv8GSDUD_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_e9DsVvBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5y0pezPC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_OiEWipTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5y0pezPC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_FOQxXdft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ko5mwmSy, 0, m, &cVar_Ko5mwmSy_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IHE2qo1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gt6fYIhR, 0, m, &cVar_Gt6fYIhR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TENy6zoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ml5527J9, 0, m, &cVar_ml5527J9_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bi6DRJiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5y0pezPC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_2YbbZUe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_5y0pezPC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_1oyFP6oV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PV4FTFt4, 0, m, &cVar_PV4FTFt4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0hCh8PE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6GWc9G2f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dgc5PdEO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_uslgnUbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aA9WVvbU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0nWOKSN_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_aA9WVvbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uxgki5ul, 1, m, &cIf_uxgki5ul_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_m0nWOKSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IWNzg94E, 0, m, &cVar_IWNzg94E_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_dgc5PdEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PV4FTFt4, 0, m, &cVar_PV4FTFt4_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_6GWc9G2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sKlWSWzv, 1, m, &cIf_sKlWSWzv_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_FNyDlvzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FOQxXdft_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_lHZBcB3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_IHE2qo1O_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_ikQHHTxs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TENy6zoB_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_UE041BDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IWNzg94E, 0, m, &cVar_IWNzg94E_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_HjwqHJKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wEDxKR0R_sendMessage(_c, 0, m);
  cMsg_0zF5TXL9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_TzcNOhzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3vptuR8_sendMessage(_c, 0, m);
  cMsg_cw9Ufda1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_P1Oke2AV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mtHl1ARA_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_ZV5ueMWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BSAXKyzb, 0, m, &cVar_BSAXKyzb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rpeHhHtp, 0, m, &cVar_rpeHhHtp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AQuSoztp, 0, m, &cVar_AQuSoztp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dJdklOMX, 0, m, &cVar_dJdklOMX_sendMessage);
  cMsg_pX4LPONC_sendMessage(_c, 0, m);
  cMsg_GxcEz6Rb_sendMessage(_c, 0, m);
  cMsg_eGyfLUXe_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_26EQTCpM, 0, m, &cVar_26EQTCpM_sendMessage);
  cMsg_TxPLTAVl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NhqZWAa5, 0, m, &cVar_NhqZWAa5_sendMessage);
  cMsg_lYuJ90ag_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8MFSqEpE, 0, m, &cVar_8MFSqEpE_sendMessage);
  cMsg_g0DzuWq5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5p4BOusn, 0, m, &cVar_5p4BOusn_sendMessage);
  cMsg_MVMmkOGN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YMPYMd6H, 0, m, &cVar_YMPYMd6H_sendMessage);
  cMsg_DLnRty3d_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_BDz01HWz, 0, m, &cVar_BDz01HWz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DxOXCT8k, 0, m, &cVar_DxOXCT8k_sendMessage);
  cMsg_ATUTELkV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NHrwzgo1, 0, m, &cVar_NHrwzgo1_sendMessage);
  cMsg_2PzOfSyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_yn8FDu6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_30UdZL9P_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_RgRCEaM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yv33RGcG, 0, m, &cVar_Yv33RGcG_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_auBMXn1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2hCozj8a, 0, m, &cVar_2hCozj8a_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_WBwOH9CS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uLAWOqIh_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_gxwFO989, VOf(Bf0));
    __hv_line_f(&sLine_zeFk6pyy, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_VbyPfMSZ, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_4N8lnchi, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_dPqDRblm, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_JkjsrNEk, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_1HvihHyN, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_kk8ygNHo, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_MEXulILt, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_61g6OSaT, VOf(Bf0));
    __hv_line_f(&sLine_gLw4oy6q, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_D9sEyqX6, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_KnM4ELNa, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_5LgDs90I, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_Z5qwjVKB, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_5S5weeRm, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_JsBZI3XX, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_fnkWmsnG, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_2OAluRwq, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_vixq5Sy5, VIf(Bf0));
    __hv_varread_f(&sVarf_y4iE2sk2, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_6o8cDw3J, VIf(Bf0));
    __hv_varread_f(&sVarf_H6e5FeTl, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_txD6DgY9, VOf(Bf1));
    __hv_rpole_f(&sRPole_zmvoENBp, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5QABb7iq, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_dqwK7xJ8, VOf(Bf1));
    __hv_rpole_f(&sRPole_j9VqJVLq, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_HrQ4YocT, VOf(Bf0));
    __hv_rpole_f(&sRPole_VPBHWT7u, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_6weNRpqS, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_1AHcQzVE, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_NP6N0s0p, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_bmar2HZ6, VOf(Bf0));
    __hv_varread_f(&sVarf_PXk0bL5q, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_9KITpXg2, VOf(Bf4));
    __hv_rpole_f(&sRPole_zNmb6EIY, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_YzlDBGEp, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_wQK5cYWk, VOf(Bf4));
    __hv_rpole_f(&sRPole_qYY1qWxi, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_VgP2w9PN, VOf(Bf6));
    __hv_rpole_f(&sRPole_xVcd8lRH, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_dqJ3X2xH, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_9OJvCfma, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_uqfiFSQu, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_ow0ttbRE, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_2OAluRwq, VIf(Bf6));
    __hv_line_f(&sLine_OM3ucBfz, VOf(Bf6));
    __hv_line_f(&sLine_cfv8n2I7, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_y4iE2sk2, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
