/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalRPole.h"
#include "HvControlDelay.h"
#include "HvControlBinop.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvSignalVar.h"
#include "HvSignalDel1.h"
#include "HvControlVar.h"
#include "HvSignalTabread.h"
#include "HvSignalTabwrite.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"
#include "HvControlCast.h"
#include "HvControlIf.h"
#include "HvMath.h"
#include "HvTable.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_Gt6fYIhR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1cSS2mOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ml5527J9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ko5mwmSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qUdvZZe7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_PfMhLTu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BSAXKyzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_A2BuAynL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5y0pezPC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4kcN9iZZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rpeHhHtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nkkRLXOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wPAmgskD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_soPyc0SF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AQuSoztp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zYyULKgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mtHl1ARA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JFvB0X4P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_m8OqmaYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HEpwEQUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wWIHkNXg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n2iE2Lnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DzqB5EWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kq2ORtgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VHM5HWLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DS44BL5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b7ruB66S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qow1HSfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FbnY3yAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_30UdZL9P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UorI8FTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DKAizPvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IG2Or2Bt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x4J6TZkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uW7jVuwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nHrKD2To_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mGJkQ9Xj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JVLRZIjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k93fES3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cmJ6iSut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Id2ZQVr7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_t4rIlW9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dJdklOMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IBXjcjsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pX4LPONC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_v3Jcp9AY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3RASuu54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_sIDPMvPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_i64sUe8i_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_if17F6Pn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TfV2blPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kfjPyJZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5mf3ffbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Uj2UCjSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IC7fq1rJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z4mM64pt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BHuLcZ2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GxcEz6Rb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_e4Psc7F9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_f0SNyO9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_czikzJ3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jWmguPP4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_bYn3nXTC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LUzDY6gR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n9p7YZ2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JvxVfugE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j4vk8QDx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mxFMT6MC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dZJEczVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gCJpdZ2A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_26EQTCpM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eGyfLUXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lFIXYn0w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j2WjOsjY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t0wxXTvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AkkhdyTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZW80hD8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LLEBW9WD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wl6dWnnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NhqZWAa5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TxPLTAVl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LR8oAYdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kK8ajIi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zntMxoWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BTRFSUi0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z8g934bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YlxKu07g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FpPfT3lD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jwMjB3VK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yI1JxFyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8MFSqEpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lYuJ90ag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mJ33lsU0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_43BqP3OL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KmnehYSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zl3gbX5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rr9HGhMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y5KwaLdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kUbJqQCv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N07ovToK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CtNdzgpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ATUTELkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FwGP8BAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DxOXCT8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HUmXfqeH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vKt4qXdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NxE6mV5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x1Ys8Ap9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2PzOfSyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LIcPHpFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NHrwzgo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ibj1drtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PI2tcDDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w93A4aDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qvgpeR8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5p4BOusn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g0DzuWq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fHYsC60H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lv4ytro0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wT7iOfyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HiDsDmja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W07SYIhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2VQTX5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rDcVSxWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YMPYMd6H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MVMmkOGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_421FS7Em_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qbpMnPmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4TccUNwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fz2GaDPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PJJxh7cP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s3GyVxpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dwcd2lMm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gmuji5rl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hpgBxkzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BDz01HWz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DLnRty3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VCUUr2Ls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1dpI2xap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cuUIGE70_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LLaYLMl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oc8vIAU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MsQWFtcD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NX7WUN9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NX1FtGcD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jpnTduaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wLUJNAjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zvhQvLju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ByiYYReI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gjPn36df_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PuOeIAYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vamQSROo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wkSMhsYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OsaVzxSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wEDxKR0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0zF5TXL9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K3vptuR8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cw9Ufda1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Yv33RGcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_knJVgA6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sKlWSWzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uxgki5ul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IWNzg94E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PV4FTFt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OtRIvBLG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_S2jk4WxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_A6l08kyu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_KqYOxfcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_5AK9wjlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rUHOnXCp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Tl6386OE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EcNMKCGA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yom9uCST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JPOA9hWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nCAvHKZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QSPya0fY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2hCozj8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uLAWOqIh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_RYyNaK7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_42uOg0ob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ogSClmNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CCnpsCK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ijXrf6wi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vn1HY2wv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oDVHrlyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oeXHqgNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Pm6RdNSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ADdob9vp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jOoQfPg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vQ21mnwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J363i4NE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rj9cflCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q91CPWk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VtbWcpR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VcoLRQ3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wv8GSDUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lsxyebbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bPZzxKDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UAA8ISVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UmVDlqLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4PQTAu2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u035d6dc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cWbObzA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RITZ3aTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_spHcvZFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oSUxAq7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ElaMHQ0X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9aHh0TRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ojC8jOVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dNzZUP2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e9DsVvBS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OiEWipTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FOQxXdft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IHE2qo1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TENy6zoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bi6DRJiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2YbbZUe9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1oyFP6oV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0hCh8PE0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uslgnUbr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aA9WVvbU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m0nWOKSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dgc5PdEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6GWc9G2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FNyDlvzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lHZBcB3r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ikQHHTxs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UE041BDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HjwqHJKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TzcNOhzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P1Oke2AV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZV5ueMWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yn8FDu6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RgRCEaM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_auBMXn1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WBwOH9CS_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_gxwFO989;
  SignalLine sLine_zeFk6pyy;
  SignalTabhead sTabhead_VbyPfMSZ;
  SignalTabread sTabread_1HvihHyN;
  SignalTabread sTabread_kk8ygNHo;
  SignalLine sLine_MEXulILt;
  SignalLine sLine_61g6OSaT;
  SignalLine sLine_gLw4oy6q;
  SignalTabhead sTabhead_D9sEyqX6;
  SignalTabread sTabread_5S5weeRm;
  SignalTabread sTabread_JsBZI3XX;
  SignalLine sLine_fnkWmsnG;
  SignalTabwrite sTabwrite_vixq5Sy5;
  SignalTabwrite sTabwrite_6o8cDw3J;
  SignalRPole sRPole_zmvoENBp;
  SignalRPole sRPole_j9VqJVLq;
  SignalRPole sRPole_VPBHWT7u;
  SignalDel1 sDel1_6weNRpqS;
  SignalLine sLine_NP6N0s0p;
  SignalLine sLine_bmar2HZ6;
  SignalRPole sRPole_zNmb6EIY;
  SignalRPole sRPole_qYY1qWxi;
  SignalRPole sRPole_xVcd8lRH;
  SignalDel1 sDel1_dqJ3X2xH;
  SignalLine sLine_uqfiFSQu;
  SignalLine sLine_ow0ttbRE;
  SignalLine sLine_OM3ucBfz;
  SignalLine sLine_cfv8n2I7;
  ControlVar cVar_Gt6fYIhR;
  ControlVar cVar_1cSS2mOT;
  ControlVar cVar_ml5527J9;
  ControlVar cVar_Ko5mwmSy;
  ControlSlice cSlice_PfMhLTu0;
  ControlVar cVar_BSAXKyzb;
  ControlSlice cSlice_4kcN9iZZ;
  ControlVar cVar_rpeHhHtp;
  ControlSlice cSlice_soPyc0SF;
  ControlVar cVar_AQuSoztp;
  ControlBinop cBinop_mtHl1ARA;
  ControlBinop cBinop_JFvB0X4P;
  ControlBinop cBinop_wWIHkNXg;
  ControlBinop cBinop_n2iE2Lnq;
  ControlBinop cBinop_VHM5HWLP;
  ControlBinop cBinop_b7ruB66S;
  ControlBinop cBinop_qow1HSfJ;
  ControlBinop cBinop_FbnY3yAX;
  ControlBinop cBinop_30UdZL9P;
  ControlBinop cBinop_UorI8FTr;
  ControlBinop cBinop_DKAizPvL;
  ControlBinop cBinop_IG2Or2Bt;
  ControlBinop cBinop_nHrKD2To;
  ControlBinop cBinop_JVLRZIjp;
  ControlBinop cBinop_k93fES3M;
  ControlBinop cBinop_cmJ6iSut;
  ControlSlice cSlice_t4rIlW9t;
  ControlVar cVar_dJdklOMX;
  ControlDelay cDelay_3RASuu54;
  ControlDelay cDelay_sIDPMvPa;
  ControlBinop cBinop_if17F6Pn;
  HvTable hTable_TfV2blPI;
  ControlBinop cBinop_5mf3ffbI;
  ControlDelay cDelay_f0SNyO9j;
  ControlDelay cDelay_czikzJ3U;
  ControlBinop cBinop_bYn3nXTC;
  HvTable hTable_LUzDY6gR;
  ControlBinop cBinop_JvxVfugE;
  ControlVar cVar_26EQTCpM;
  ControlBinop cBinop_j2WjOsjY;
  ControlBinop cBinop_t0wxXTvj;
  SignalVarf sVarf_txD6DgY9;
  ControlBinop cBinop_ZW80hD8g;
  ControlBinop cBinop_LLEBW9WD;
  ControlBinop cBinop_wl6dWnnx;
  SignalVarf sVarf_H6e5FeTl;
  ControlVar cVar_NhqZWAa5;
  ControlBinop cBinop_kK8ajIi3;
  ControlBinop cBinop_zntMxoWr;
  SignalVarf sVarf_dqwK7xJ8;
  ControlBinop cBinop_Z8g934bb;
  ControlBinop cBinop_YlxKu07g;
  ControlBinop cBinop_FpPfT3lD;
  SignalVarf sVarf_5QABb7iq;
  ControlBinop cBinop_jwMjB3VK;
  ControlBinop cBinop_yI1JxFyE;
  SignalVarf sVarf_HrQ4YocT;
  ControlVar cVar_8MFSqEpE;
  ControlBinop cBinop_43BqP3OL;
  ControlBinop cBinop_KmnehYSy;
  ControlBinop cBinop_rr9HGhMV;
  ControlBinop cBinop_y5KwaLdt;
  ControlBinop cBinop_kUbJqQCv;
  ControlBinop cBinop_N07ovToK;
  ControlBinop cBinop_CtNdzgpN;
  SignalVarf sVarf_1AHcQzVE;
  ControlVar cVar_DxOXCT8k;
  ControlBinop cBinop_vKt4qXdf;
  ControlBinop cBinop_x1Ys8Ap9;
  SignalVarf sVarf_JkjsrNEk;
  SignalVarf sVarf_4N8lnchi;
  SignalVarf sVarf_dPqDRblm;
  ControlVar cVar_NHrwzgo1;
  ControlBinop cBinop_PI2tcDDy;
  ControlBinop cBinop_qvgpeR8j;
  SignalVarf sVarf_Z5qwjVKB;
  SignalVarf sVarf_KnM4ELNa;
  SignalVarf sVarf_5LgDs90I;
  ControlVar cVar_5p4BOusn;
  ControlBinop cBinop_Lv4ytro0;
  ControlBinop cBinop_wT7iOfyf;
  SignalVarf sVarf_9KITpXg2;
  ControlBinop cBinop_W07SYIhr;
  ControlBinop cBinop_b2VQTX5T;
  ControlBinop cBinop_rDcVSxWN;
  SignalVarf sVarf_PXk0bL5q;
  ControlVar cVar_YMPYMd6H;
  ControlBinop cBinop_qbpMnPmt;
  ControlBinop cBinop_4TccUNwG;
  SignalVarf sVarf_wQK5cYWk;
  ControlBinop cBinop_PJJxh7cP;
  ControlBinop cBinop_s3GyVxpK;
  ControlBinop cBinop_Dwcd2lMm;
  SignalVarf sVarf_YzlDBGEp;
  ControlBinop cBinop_Gmuji5rl;
  ControlBinop cBinop_hpgBxkzx;
  SignalVarf sVarf_VgP2w9PN;
  ControlVar cVar_BDz01HWz;
  ControlBinop cBinop_1dpI2xap;
  ControlBinop cBinop_cuUIGE70;
  ControlBinop cBinop_Oc8vIAU3;
  ControlBinop cBinop_MsQWFtcD;
  ControlBinop cBinop_NX7WUN9W;
  ControlBinop cBinop_NX1FtGcD;
  ControlBinop cBinop_jpnTduaf;
  SignalVarf sVarf_9OJvCfma;
  SignalVarf sVarf_2OAluRwq;
  SignalVarf sVarf_y4iE2sk2;
  ControlVar cVar_Yv33RGcG;
  ControlBinop cBinop_knJVgA6S;
  ControlIf cIf_sKlWSWzv;
  ControlIf cIf_uxgki5ul;
  ControlVar cVar_IWNzg94E;
  ControlVar cVar_PV4FTFt4;
  ControlVar cVar_OtRIvBLG;
  ControlVar cVar_S2jk4WxG;
  ControlSlice cSlice_KqYOxfcu;
  ControlSlice cSlice_5AK9wjlz;
  ControlVar cVar_rUHOnXCp;
  ControlIf cIf_Tl6386OE;
  ControlBinop cBinop_JPOA9hWr;
  ControlVar cVar_2hCozj8a;
  ControlBinop cBinop_Rj9cflCT;
  ControlBinop cBinop_Q91CPWk9;
  ControlBinop cBinop_FOQxXdft;
  ControlBinop cBinop_IHE2qo1O;
  ControlBinop cBinop_TENy6zoB;
  ControlBinop cBinop_1oyFP6oV;
  ControlBinop cBinop_0hCh8PE0;
  ControlBinop cBinop_uslgnUbr;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
